﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Runtime.InteropServices;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using Testing.SimpleMFPlayer.MediaPlayer;

namespace Testing.SimpleMFPlayerV3
{
    public partial class MainWindow : Form
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="MainWindow"/> class.
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Updates the state of this dialog.
        /// </summary>
        private void UpdateDialogState()
        {
            if (m_mediaPlayer.State == MFMediaPlayerState.NothingToDo)
            {
                m_mnuLblVideoFile.Text = "No Video loaded..";
                m_mnuCmdOpenVideo2.Enabled = true;
                m_mnuCmdCloseVideo2.Enabled = false;
                m_mnuCmdPause.Enabled = false;
                m_mnuCmdResume.Enabled = false;
            }
            else
            {
                m_mnuLblVideoFile.Text = m_mediaPlayer.CurrentVideoFile;
                m_mnuCmdOpenVideo2.Enabled = false;
                m_mnuCmdCloseVideo2.Enabled = true;
                m_mnuCmdPause.Enabled = !m_mediaPlayer.IsPaused;
                m_mnuCmdResume.Enabled = m_mediaPlayer.IsPaused;
            }
        }

        /// <summary>
        /// Default load event. 
        /// </summary>
        /// <param name="e"></param>
        protected override void OnLoad(EventArgs e)
        {
            base.OnLoad(e);

            if (this.DesignMode) { return; }

            UpdateDialogState();
        }

        /// <summary>
        /// Called when user clicks exit.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="EventArgs"/> instance containing the event data.</param>
        private void OnMnuCmdExitClick(object sender, EventArgs e)
        {
            this.Close();
        }

        /// <summary>
        /// Called when user wants to open a video.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="EventArgs"/> instance containing the event data.</param>
        private async void OnMnuCmdOpenVideoClick(object sender, EventArgs e)
        {
            // Query for source file
            if (m_dlgOpenVideoFile.ShowDialog(this) != DialogResult.OK) { return; }
            string sourceVideoFile = m_dlgOpenVideoFile.FileName;

            // Start playing given video file
            await m_mediaPlayer.OpenAndShowVideoFileAsync(sourceVideoFile);

            // Update the state of the dialog
            this.UpdateDialogState();
        }

        /// <summary>
        /// Called when user wants to close the currently running video.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="EventArgs"/> instance containing the event data.</param>
        private async void OnMnuCmdCloseVideoClick(object sender, EventArgs e)
        {
            // Close current media session
            await m_mediaPlayer.CloseVideoAsync();

            // Update the state of the dialog
            this.UpdateDialogState();
        }

        /// <summary>
        /// Called when the state of the media player has changed.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="EventArgs"/> instance containing the event data.</param>
        private void OnMediaPlayerStateChanged(object sender, EventArgs e)
        {
            // Update common control states
            this.UpdateDialogState();

            // Invalidate the window
            this.Invalidate(true);
        }

        /// <summary>
        /// Called when the pause state of the media player has changed.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="EventArgs"/> instance containing the event data.</param>
        private void OnMediaPlayerIsPausedChanged(object sender, EventArgs e)
        {
            if(m_mediaPlayer.State == MFMediaPlayerState.Playing)
            {
                this.UpdateDialogState();
            }
        }

        /// <summary>
        /// Called when user wants to pause the video.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="EventArgs"/> instance containing the event data.</param>
        private async void OnMnuCmdPauseClick(object sender, EventArgs e)
        {
            await m_mediaPlayer.PauseVideoAsync();
        }

        /// <summary>
        /// Called when user wants to resume the video.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="EventArgs"/> instance containing the event data.</param>
        private async void OnMnuCmdResumeClick(object sender, EventArgs e)
        {
            await m_mediaPlayer.ResumeVideoAsync();
        }
    }
}
